==> haskell-network-udp-0.0.0-134.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-EL7cgW0kYJA3uRLstuwdoJ
key:                  network-udp-0.0.0-EL7cgW0kYJA3uRLstuwdoJ
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  cb81761aeb39bf811c932d79a54d07a4
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-EL7cgW0kYJA3uRLstuwdoJ
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-8MQv32arzXu8ybbx4AUApr
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-udp-0.0.0-135-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-udp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-udp
version:              0.0.0
visibility:           public
id:                   network-udp-0.0.0-BkltWFFDBohIZQT572OUWY
key:                  network-udp-0.0.0-BkltWFFDBohIZQT572OUWY
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             UDP library
description:          Best current practice library for UDP clients and servers.
category:             Network
abi:                  7e0225c83db6ec8a1b7639f4781e8229
exposed:              True
exposed-modules:      Network.UDP
hidden-modules:       Network.UDP.Recv Network.UDP.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-udp-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-udp
hs-libraries:         HSnetwork-udp-0.0.0-BkltWFFDBohIZQT572OUWY
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    iproute-1.7.15-G8PIBt0bMmIHonL1qb456T
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ

haddock-interfaces:   /usr/share/doc/haskell-network-udp/html/network-udp.haddock
haddock-html:         /usr/share/doc/haskell-network-udp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
